function [x_opt,y_opt,maxL]=gm_print_points_Lebesgue_diskR(degree,epsi,iprint,nfev,x0,y0);
%GM_PRINT_POINTS_LEBESGUE_DISKR prints sets of points for the unit disk using Lebesgue constant minimization 

% used for refinement

% given starting points

% Input:
% degree = given degree
% epsi = stopping criteria on the value of the objective function
% iprint = 1 with printing
% nfev = approximate maximum number of function evaluations in praxis
% x0, y0 = starting points
%
% Output:
% x_opt, y_opt = coordinates of the set of points
% maxL  = approximate Lebesgue constant
%

%
% Author G. Meurant
% February 2017
%

global WAM

global V_pts

if nargin < 3
 iprint = 0;
end

if nargin < 4
 nfev = 2000;
end 

ii = sqrt(-1);

if degree > 20
 fprintf('\n gm_print_points_Lebesgue_disk: The degree may be too large, be patient! \n\n')
end
  
pb = 'disk';
  
if iprint == 1
 fprintf('\n Degree = %d, Problem %s \n\n',degree,pb)
end

% equal weights
n = ((degree + 1) * (degree + 2)) / 2;
w = ones(n,1) / n;

if nargin < 6
 
 % Leja-like points for starting
 leja = gm_leja_disk(degree);
 x0 = leja(:,1);
 y0 = leja(:,2);
 
end % if nargin

if iprint == 1
 % recompute the Lebesgue contant
 XY = gm_disk_wam(500);
 % this may not be enough to compute the L-constant reliably!!!!!!
 [Psinp,maxL,Psidot,XY] = gm_comp_Lebesgue_func_OPHL(x0,y0,w,400,2);
 fprintf('\n Lebesgue constant initial points = %g \n',maxL)
end

% Lebesgue minimization

if iprint == 1
 fprintf('\n --------Start of Lebesgue constant minimization \n\n')
end

[xl,yl,maxLl] = gm_min_praxis_Lebesgue_diskR(x0,y0,w,epsi,iprint,nfev);

if iprint == 1
 gm_print_points(xl,yl);
end

if iprint == 1
 fprintf('\n --------End of the Lebesgue constant minimization, Lebesgue constant = %g \n',maxLl)
 pause
 gm_clearallfig
end

% refinement algorithm

it = 3; % number of iterations

if iprint == 1
 fprintf('\n --------Start of refinement, %d iterations \n',it)
end

[xr,yr,Psinp,maxLr,x_opt,y_opt] = gm_Leb_ref_disk(xl,yl,w,xl,yl,maxLl,it,iprint);

% best points so far
if iprint == 1
 gm_print_points(x_opt,y_opt);
end

if iprint == 1
 fprintf('\n --------End of the refinement, Lebesgue constant after this step = %g \n',maxLr)
 pause
 gm_clearallfig
end

% x_opt = xl; y_opt = yl;
% maxLr = maxLl;

% one point minimization

it = 5; % number of iterations

if iprint == 1
 fprintf('\n --------Start of one point minimization, %d iterations \n',it)
end

[x1,y1,Psinp,maxL1,x_opt,y_opt]=gm_Leb_one_disk_V(x_opt,y_opt,w,x_opt,y_opt,maxLr,it,epsi,iprint);

% Leja order of the best points
z = gm_leja_ord(x_opt + ii * y_opt,n);
x_opt = real(z);
y_opt = imag(z);

% best points so far
if iprint == 1
 gm_print_points(x_opt,y_opt);
end

if iprint == 1
 fprintf('\n --------End of the one point minimization, Lebesgue constant after this step = %g \n',maxL1)
end

% recompute the Lebesgue contant
XY = gm_disk_wam(500);
% [Psinp,maxL,Psidot,XY] = gm_comp_Lebesgue_func_OPHL(x_opt,y_opt,w,400,2);
[maxL,Psidot] = gm_compXY_Lebesgue_func_OPHL(x_opt,y_opt,w,XY,2);

if iprint == 1
 fprintf('\n end of degree %d, Lebesgue constant = %g \n',degree,maxL)
 fprintf('\n -------------------------------------------------------------------- \n')
end







