function [x_opt,y_opt,maxL]=gm_write_min_L2norm_bnd(x0,y0,w,epsi,mu,ipb,iprint);
%GM_WRITE_MIN_L2NORM_BND writes sets of points using l_2 minimization + a boundary integral

% the number of starting points must correspond to a degree
%   N = (d+1)(d+2)/2

% Input:
% (x0,y0) = starting points
% w = weights (sum(w) = 1)
% epsi = stopping criteria on the value of the objective function
% mu = coefficient of the boundary integral
% ipb = problem to be considered
%        ipb = 1 square
%        ipb = 2 disk
%        ipb = 3 L-shape region
%        ipb = 4 triangle (simplex)
%        ipb = 5 double bubble
%        ipb = 6 ellipse
%        ipb = 7 half-ellipse
% iprint = 1, printing
%
% Output
% x_opt, y_opt = coordinates of the best set of points

%
% Author G. Meurant
% August 2015
%

if nargin < 7
 iprint = 0;
end

% you may have to change this
fpath = 'C:\D\new_mfiles\gm_toolbox\Interpolation\Examples\';

n = length(x0);
degree = ceil((-3 + sqrt(1 + 8 * n)) / 2);

switch ipb
 
 case 1
  pb = 'square';
  
 case 2
  
  pb = 'disk';
  
 case 3
  
  pb = 'Lshape';
  
 case 4
  
  pb = 'triangle';
  
 case 5
  
  pb = 'dbubble';
  
 case 6
  
  pb = 'ellipse';
  
 case 7
  
  pb = 'hellipse';
  
 otherwise
  
  error('gm_write_min_L2norm_bnd: Wrong value of ipb')
  
end % switch


% construct the name of the file
nstr = num2str((mu-fix(mu))*100);
if mu-fix(mu) == 0
 if fix(mu) == 0
  nstr = '0';
 else
  nstr = '00';
 end % if
end % if mu

fnam = [fpath 'gm_' pb num2str(degree) '-' num2str(fix(mu)) nstr];

% L2 norm minimization

if iprint == 1
 fprintf('\n --------Start of l2 minimization \n\n')
end

[xl,yl,maxLl] = gm_min_praxis_L2norm_bnd(x0,y0,w,epsi,mu,ipb,iprint);

fname = [fnam '-l2'];

gm_write_points(fname,xl,yl);

if iprint == 1
 fprintf('\n --------End of the L2 minimization, mu = %g Lebesgue constant = %g \n',mu,maxLl)
 pause
 gm_clearallfig
end

% refinement algorithm

it = 3; % number of iterations

if iprint == 1
 fprintf('\n --------Start of refinement, %d iterations \n',it)
end
 
[xr,yr,Psinp,maxLr,x_opt,y_opt] = gm_Leb_refP_OPHL(xl,yl,w,xl,yl,maxLl,it,epsi,iprint);

fname = [fnam '-ref'];

gm_write_points(fname,xr,yr);

if iprint == 1
 fprintf('\n --------End of the refinement, Lebesgue constant after this step = %g \n',maxLr)
 pause
 gm_clearallfig
end

% one point minimization

if iprint == 1
 fprintf('\n --------Start of one point minimization, %d iterations \n',it)
end

[x1,y1,Psinp,maxL1,x_opt,y_opt]=gm_Leb_one_OPHL(xr,yr,w,x_opt,y_opt,maxLr,it,epsi,iprint);

fname = [fnam '-1p'];

gm_write_points(fname,x1,y1);

x = x_opt;
y = y_opt;

if iprint == 1
 fprintf('\n --------End of the one point minimization, Lebesgue constant = %g \n',maxL1)
 pause
 gm_clearallfig
end

 % recompute the Lebesgue contant
 % this may not be enough to compute the L-constant reliably!!!!!!
if iprint == 1
 [Psinp,maxL,Psidot,XY] = gm_viz_Lebesgue_func_OPHL(x,y,w,200,ipb);
end

[Psinp,maxL,Psidot,XY] = gm_comp_Lebesgue_func_OPHL(x,y,w,400,ipb);

if iprint == 1
 fprintf('\n end of degree %d, Lebesgue constant = %g \n',degree,maxL)
 fprintf('\n -------------------------------------------------------------------- \n')
end





