function leja=gm_leja_disk(deg);
%GM_LEJA_DISK Leja-like points in the unit disk, center (0,0), radius 1

% Input:
% deg = degree of the bivariate polynomial
%       it yields (deg + 1) * (deg + 2) / 2 points
%
% Output:
% leja = coordinates of the points, x = leja(:,1), y = leja(:,2)

%
% adapted from M. Vianello
% May 2014
% Updated by G. Meurant
% July 2015
%

dim = (deg +1 ) * (deg + 2) / 2;

if deg == 1
 % use arbitrary points
 leja = zeros(dim,1);
 leja(1,1) = 0; leja(1,2) = 0.5;
 leja(2,1) = 0.5; leja(2,2) = 0;
 leja(3,1) = -0.5; leja(3,2) = 0;
 return
end

rect = [-1 1 -1 1];

H = gm_haltonseq(deg^3,2);
x = 2 * H(:,1) - 1;
y = 2 * H(:,2) - 1;
H(:,1) = x; 
H(:,2) = y;

% keep the points in the disk
ind = find((H(:,1)).^2+(H(:,2)).^2 < 1);
gmmesh = H(ind,:);

% computing the rectangular Chebyshev-Vandermonde matrix on the mesh

V = gm_chebvand(deg,gmmesh,rect);

% computing the approximate Leja points using the LU factorization

[L,U,perm] = lu(V,'vector');
leja = gmmesh(perm(1:dim),:);







